@@ -10,9 +10,15 @@
 """
 import logging
 
-from sqlalchemy import Column, DateTime, Boolean
-from sqlalchemy import Integer, String
-from vortex.Tuple import Tuple, addTupleType
+from sqlalchemy import Boolean
+from sqlalchemy import Column
+from sqlalchemy import DateTime
+from sqlalchemy import Integer
+from sqlalchemy import String
+
+from peek_core_user.tuples.UserLoggedInInfoTuple import UserLoggedInInfoTuple
+from vortex.Tuple import Tuple
+from vortex.Tuple import addTupleType
 
 from peek_core_user._private.PluginNames import userPluginTuplePrefix
 from peek_core_user._private.storage.DeclarativeBase import DeclarativeBase
@@ -22,13 +28,14 @@ logger = logging.getLogger(__name__)
 
 @addTupleType
 class UserLoggedIn(Tuple, DeclarativeBase):
-    """ UserLoggedIn
+    """UserLoggedIn
 
     This table stores which users are logged into which devices
 
     """
-    __tupleType__ = userPluginTuplePrefix + 'UserLoggedIn'
-    __tablename__ = 'UserLoggedIn'
+
+    __tupleType__ = userPluginTuplePrefix + "UserLoggedIn"
+    __tablename__ = "UserLoggedIn"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     loggedInDateTime = Column(DateTime(True), nullable=False)
@@ -36,3 +43,12 @@ class UserLoggedIn(Tuple, DeclarativeBase):
     deviceToken = Column(String(100), unique=True, nullable=False)
     vehicle = Column(String)
     isFieldLogin = Column(Boolean)
+
+    def toTuple(self):
+        return UserLoggedInInfoTuple(
+            loggedInDateTime=self.loggedInDateTime,
+            userName=self.userName,
+            deviceToken=self.deviceToken,
+            vehicle=self.vehicle,
+            isFieldLogin=self.isFieldLogin,
+        )
